@@ -6,7 +6,7 @@ use rustc_hash::FxHashMap;
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 use uv_fs::{LockedFile, LockedFileError, LockedFileMode, with_added_extension};
-use uv_preview::{Preview, PreviewFeatures};
+use uv_preview::{Preview, PreviewFeature};
 use uv_redacted::DisplaySafeUrl;
 
 use uv_state::{StateBucket, StateStore};
@@ -30,7 +30,7 @@ pub enum AuthBackend {
 impl AuthBackend {
     pub async fn from_settings(preview: Preview) -> Result<Self, TomlCredentialError> {
         // If preview is enabled, we'll use the system-native store
-        if preview.is_enabled(PreviewFeatures::NATIVE_AUTH) {
+        if preview.is_enabled(PreviewFeature::NativeAuth) {
             return Ok(Self::System(KeyringProvider::native()));
         }
 
