@@ -30,7 +30,7 @@ use tokio::sync::{Mutex, Semaphore};
 use tracing::{Instrument, debug, info_span, instrument, warn};
 use uv_auth::CredentialsCache;
 use uv_cache_key::cache_digest;
-use uv_configuration::{BuildKind, BuildOutput, SourceStrategy};
+use uv_configuration::{BuildKind, BuildOutput, NoSources};
 use uv_distribution::BuildRequires;
 use uv_distribution_types::{
     ConfigSettings, ExtraBuildRequirement, ExtraBuildRequires, IndexLocations, Requirement,
@@ -282,7 +282,7 @@ impl SourceBuild {
         source_build_context: SourceBuildContext,
         version_id: Option<&str>,
         locations: &IndexLocations,
-        source_strategy: SourceStrategy,
+        no_sources: NoSources,
         workspace_cache: &WorkspaceCache,
         config_settings: ConfigSettings,
         build_isolation: BuildIsolation<'_>,
@@ -309,7 +309,7 @@ impl SourceBuild {
             install_path,
             fallback_package_name,
             locations,
-            source_strategy,
+            &no_sources,
             workspace_cache,
             credentials_cache,
         )
@@ -445,7 +445,7 @@ impl SourceBuild {
                 package_version.as_ref(),
                 version_id,
                 locations,
-                source_strategy,
+                no_sources,
                 workspace_cache,
                 build_stack,
                 build_kind,
@@ -561,7 +561,7 @@ impl SourceBuild {
         install_path: &Path,
         package_name: Option<&PackageName>,
         locations: &IndexLocations,
-        source_strategy: SourceStrategy,
+        no_sources: &NoSources,
         workspace_cache: &WorkspaceCache,
         credentials_cache: &CredentialsCache,
     ) -> Result<(Pep517Backend, Option<Project>), Box<Error>> {
@@ -574,42 +574,35 @@ impl SourceBuild {
 
                 let backend = if let Some(build_system) = pyproject_toml.build_system {
                     // If necessary, lower the requirements.
-                    let requirements = match source_strategy {
-                        SourceStrategy::Enabled => {
-                            if let Some(name) = pyproject_toml
-                                .project
-                                .as_ref()
-                                .map(|project| &project.name)
-                                .or(package_name)
-                            {
-                                let build_requires = uv_pypi_types::BuildRequires {
-                                    name: Some(name.clone()),
-                                    requires_dist: build_system.requires,
-                                };
-                                let build_requires = BuildRequires::from_project_maybe_workspace(
-                                    build_requires,
-                                    install_path,
-                                    locations,
-                                    source_strategy,
-                                    workspace_cache,
-                                    credentials_cache,
-                                )
-                                .await
-                                .map_err(Error::Lowering)?;
-                                build_requires.requires_dist
-                            } else {
-                                build_system
-                                    .requires
-                                    .into_iter()
-                                    .map(Requirement::from)
-                                    .collect()
-                            }
-                        }
-                        SourceStrategy::Disabled => build_system
+                    let requirements = if let Some(name) = pyproject_toml
+                        .project
+                        .as_ref()
+                        .map(|project| &project.name)
+                        .or(package_name)
+                        // If sources are disabled, there's nothing to do here
+                        .filter(|_| !no_sources.all())
+                    {
+                        let build_requires = uv_pypi_types::BuildRequires {
+                            name: Some(name.clone()),
+                            requires_dist: build_system.requires,
+                        };
+                        let build_requires = BuildRequires::from_project_maybe_workspace(
+                            build_requires,
+                            install_path,
+                            locations,
+                            no_sources,
+                            workspace_cache,
+                            credentials_cache,
+                        )
+                        .await
+                        .map_err(Error::Lowering)?;
+                        build_requires.requires_dist
+                    } else {
+                        build_system
                             .requires
                             .into_iter()
                             .map(Requirement::from)
-                            .collect(),
+                            .collect()
                     };
 
                     Pep517Backend {
@@ -956,7 +949,7 @@ async fn create_pep517_build_environment(
     package_version: Option<&Version>,
     version_id: Option<&str>,
     locations: &IndexLocations,
-    source_strategy: SourceStrategy,
+    no_sources: NoSources,
     workspace_cache: &WorkspaceCache,
     build_stack: &BuildStack,
     build_kind: BuildKind,
@@ -1048,25 +1041,24 @@ async fn create_pep517_build_environment(
     };
 
     // If necessary, lower the requirements.
-    let extra_requires = match source_strategy {
-        SourceStrategy::Enabled => {
-            let build_requires = uv_pypi_types::BuildRequires {
-                name: package_name.cloned(),
-                requires_dist: extra_requires,
-            };
-            let build_requires = BuildRequires::from_project_maybe_workspace(
-                build_requires,
-                install_path,
-                locations,
-                source_strategy,
-                workspace_cache,
-                credentials_cache,
-            )
-            .await
-            .map_err(Error::Lowering)?;
-            build_requires.requires_dist
-        }
-        SourceStrategy::Disabled => extra_requires.into_iter().map(Requirement::from).collect(),
+    let extra_requires = if no_sources.all() {
+        extra_requires.into_iter().map(Requirement::from).collect()
+    } else {
+        let build_requires = uv_pypi_types::BuildRequires {
+            name: package_name.cloned(),
+            requires_dist: extra_requires,
+        };
+        let build_requires = BuildRequires::from_project_maybe_workspace(
+            build_requires,
+            install_path,
+            locations,
+            &no_sources,
+            workspace_cache,
+            credentials_cache,
+        )
+        .await
+        .map_err(Error::Lowering)?;
+        build_requires.requires_dist
     };
 
     // Some packages (such as tqdm 4.66.1) list only extra requires that have already been part of
