@@ -3,8 +3,9 @@ use std::path::Path;
 use std::slice;
 
 use rustc_hash::FxHashSet;
+
 use uv_auth::CredentialsCache;
-use uv_configuration::SourceStrategy;
+use uv_configuration::NoSources;
 use uv_distribution_types::{IndexLocations, Requirement};
 use uv_normalize::{ExtraName, GroupName, PackageName};
 use uv_pep508::MarkerTree;
@@ -46,7 +47,7 @@ impl RequiresDist {
         install_path: &Path,
         git_member: Option<&GitWorkspaceMember<'_>>,
         locations: &IndexLocations,
-        sources: SourceStrategy,
+        sources: NoSources,
         cache: &WorkspaceCache,
         credentials_cache: &CredentialsCache,
     ) -> Result<Self, MetadataError> {
@@ -58,9 +59,10 @@ impl RequiresDist {
                     .expect("git checkout has a parent")
                     .to_path_buf()
             }),
-            members: match sources {
-                SourceStrategy::Enabled => MemberDiscovery::default(),
-                SourceStrategy::Disabled => MemberDiscovery::None,
+            members: if sources.is_none() {
+                MemberDiscovery::default()
+            } else {
+                MemberDiscovery::None
             },
             ..DiscoveryOptions::default()
         };
@@ -75,7 +77,7 @@ impl RequiresDist {
             &project_workspace,
             git_member,
             locations,
-            sources,
+            &sources,
             credentials_cache,
         )
     }
@@ -85,37 +87,31 @@ impl RequiresDist {
         project_workspace: &ProjectWorkspace,
         git_member: Option<&GitWorkspaceMember<'_>>,
         locations: &IndexLocations,
-        source_strategy: SourceStrategy,
+        no_sources: &NoSources,
         credentials_cache: &CredentialsCache,
     ) -> Result<Self, MetadataError> {
         // Collect any `tool.uv.index` entries.
         let empty = vec![];
-        let project_indexes = match source_strategy {
-            SourceStrategy::Enabled => project_workspace
-                .current_project()
-                .pyproject_toml()
-                .tool
-                .as_ref()
-                .and_then(|tool| tool.uv.as_ref())
-                .and_then(|uv| uv.index.as_deref())
-                .unwrap_or(&empty),
-            SourceStrategy::Disabled => &empty,
-        };
+        let project_indexes = project_workspace
+            .current_project()
+            .pyproject_toml()
+            .tool
+            .as_ref()
+            .and_then(|tool| tool.uv.as_ref())
+            .and_then(|uv| uv.index.as_deref())
+            .unwrap_or(&empty);
 
         // Collect any `tool.uv.sources` and `tool.uv.dev_dependencies` from `pyproject.toml`.
         let empty = BTreeMap::default();
-        let project_sources = match source_strategy {
-            SourceStrategy::Enabled => project_workspace
-                .current_project()
-                .pyproject_toml()
-                .tool
-                .as_ref()
-                .and_then(|tool| tool.uv.as_ref())
-                .and_then(|uv| uv.sources.as_ref())
-                .map(ToolUvSources::inner)
-                .unwrap_or(&empty),
-            SourceStrategy::Disabled => &empty,
-        };
+        let project_sources = project_workspace
+            .current_project()
+            .pyproject_toml()
+            .tool
+            .as_ref()
+            .and_then(|tool| tool.uv.as_ref())
+            .and_then(|uv| uv.sources.as_ref())
+            .map(ToolUvSources::inner)
+            .unwrap_or(&empty);
 
         let dependency_groups = FlatDependencyGroups::from_pyproject_toml(
             project_workspace.current_project().root(),
@@ -130,14 +126,18 @@ impl RequiresDist {
         let dependency_groups = dependency_groups
             .into_iter()
             .map(|(name, flat_group)| {
-                let requirements = match source_strategy {
-                    SourceStrategy::Enabled => flat_group
-                        .requirements
-                        .into_iter()
-                        .flat_map(|requirement| {
+                let requirements = flat_group
+                    .requirements
+                    .into_iter()
+                    .flat_map(|requirement| {
+                        // Check if sources should be disabled for this specific package
+                        if no_sources.for_package(&requirement.name) {
+                            vec![Ok(Requirement::from(requirement))].into_iter()
+                        } else {
                             let requirement_name = requirement.name.clone();
                             let group = name.clone();
                             let extra = None;
+
                             LoweredRequirement::from_requirement(
                                 requirement,
                                 Some(&metadata.name),
@@ -151,36 +151,35 @@ impl RequiresDist {
                                 git_member,
                                 credentials_cache,
                             )
-                            .map(
-                                move |requirement| match requirement {
-                                    Ok(requirement) => Ok(requirement.into_inner()),
-                                    Err(err) => Err(MetadataError::GroupLoweringError(
-                                        group.clone(),
-                                        requirement_name.clone(),
-                                        Box::new(err),
-                                    )),
-                                },
-                            )
-                        })
-                        .collect::<Result<Box<_>, _>>(),
-                    SourceStrategy::Disabled => Ok(flat_group
-                        .requirements
-                        .into_iter()
-                        .map(Requirement::from)
-                        .collect()),
-                }?;
+                            .map(move |requirement| match requirement {
+                                Ok(requirement) => Ok(requirement.into_inner()),
+                                Err(err) => Err(MetadataError::GroupLoweringError(
+                                    group.clone(),
+                                    requirement_name.clone(),
+                                    Box::new(err),
+                                )),
+                            })
+                            .collect::<Vec<_>>()
+                            .into_iter()
+                        }
+                    })
+                    .collect::<Result<Box<_>, _>>()?;
                 Ok::<(GroupName, Box<_>), MetadataError>((name, requirements))
             })
             .collect::<Result<BTreeMap<_, _>, _>>()?;
 
         // Lower the requirements.
         let requires_dist = Box::into_iter(metadata.requires_dist);
-        let requires_dist = match source_strategy {
-            SourceStrategy::Enabled => requires_dist
-                .flat_map(|requirement| {
+        let requires_dist = requires_dist
+            .flat_map(|requirement| {
+                // Check if sources should be disabled for this specific package
+                if no_sources.for_package(&requirement.name) {
+                    vec![Ok(Requirement::from(requirement))].into_iter()
+                } else {
                     let requirement_name = requirement.name.clone();
                     let extra = requirement.marker.top_level_extra_name();
                     let group = None;
+
                     LoweredRequirement::from_requirement(
                         requirement,
                         Some(&metadata.name),
@@ -201,10 +200,11 @@ impl RequiresDist {
                             Box::new(err),
                         )),
                     })
-                })
-                .collect::<Result<Box<_>, _>>()?,
-            SourceStrategy::Disabled => requires_dist.into_iter().map(Requirement::from).collect(),
-        };
+                    .collect::<Vec<_>>()
+                    .into_iter()
+                }
+            })
+            .collect::<Result<Box<_>, _>>()?;
 
         Ok(Self {
             name: metadata.name,
@@ -443,8 +443,9 @@ mod test {
     use anyhow::Context;
     use indoc::indoc;
     use insta::assert_snapshot;
+
     use uv_auth::CredentialsCache;
-    use uv_configuration::SourceStrategy;
+    use uv_configuration::NoSources;
     use uv_distribution_types::IndexLocations;
     use uv_normalize::PackageName;
     use uv_pep508::Requirement;
@@ -478,7 +479,7 @@ mod test {
             &project_workspace,
             None,
             &IndexLocations::default(),
-            SourceStrategy::default(),
+            &NoSources::default(),
             &CredentialsCache::new(),
         )?)
     }
@@ -509,14 +510,13 @@ mod test {
             tqdm = true
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @"
         error: TOML parse error at line 8, column 8
           |
         8 | tqdm = true
           |        ^^^^
         invalid type: boolean `true`, expected a single source (as a map) or list of sources
-
-        "###);
+        ");
     }
 
     #[tokio::test]
@@ -532,13 +532,13 @@ mod test {
             tqdm = { git = "https://github.com/tqdm/tqdm", rev = "baaaaaab", tag = "v1.0.0" }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @r#"
         error: TOML parse error at line 8, column 8
           |
         8 | tqdm = { git = "https://github.com/tqdm/tqdm", rev = "baaaaaab", tag = "v1.0.0" }
           |        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
         expected at most one of `rev`, `tag`, or `branch`
-        "###);
+        "#);
     }
 
     #[tokio::test]
@@ -575,13 +575,13 @@ mod test {
             tqdm = { git = "https://github.com/tqdm/tqdm", extra = "torch", group = "dev" }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @r#"
         error: TOML parse error at line 7, column 8
           |
         7 | tqdm = { git = "https://github.com/tqdm/tqdm", extra = "torch", group = "dev" }
           |        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
         cannot specify both `extra` and `group`
-        "###);
+        "#);
     }
 
     #[tokio::test]
@@ -597,13 +597,13 @@ mod test {
             tqdm = { path = "tqdm", index = "torch" }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @r#"
         error: TOML parse error at line 8, column 8
           |
         8 | tqdm = { path = "tqdm", index = "torch" }
           |        ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
         cannot specify both `path` and `index`
-        "###);
+        "#);
     }
 
     #[tokio::test]
@@ -654,13 +654,13 @@ mod test {
             tqdm = { url = "§invalid#+#*Ä" }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @r#"
         error: TOML parse error at line 8, column 16
           |
         8 | tqdm = { url = "§invalid#+#*Ä" }
           |                ^^^^^^^^^^^^^^^^^
         relative URL without a base: "§invalid#+#*Ä"
-        "###);
+        "#);
     }
 
     #[tokio::test]
@@ -676,10 +676,10 @@ mod test {
             tqdm = { workspace = true }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @"
         error: Failed to parse entry: `tqdm`
           Caused by: `tqdm` references a workspace in `tool.uv.sources` (e.g., `tqdm = { workspace = true }`), but is not a workspace member
-        "###);
+        ");
     }
 
     #[tokio::test]
@@ -695,10 +695,10 @@ mod test {
             tqdm = { workspace = true }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
+        assert_snapshot!(format_err(input).await, @"
         error: Failed to parse entry: `tqdm`
           Caused by: `tqdm` references a workspace in `tool.uv.sources` (e.g., `tqdm = { workspace = true }`), but is not a workspace member
-        "###);
+        ");
     }
 
     #[tokio::test]
@@ -714,9 +714,7 @@ mod test {
             tqdm = { workspace = true }
         "#};
 
-        assert_snapshot!(format_err(input).await, @r###"
-        error: The following field was marked as dynamic: dependencies
-        "###);
+        assert_snapshot!(format_err(input).await, @"error: The following field was marked as dynamic: dependencies");
     }
 
     #[tokio::test]
@@ -726,9 +724,7 @@ mod test {
             tqdm = { workspace = true }
         "};
 
-        assert_snapshot!(format_err(input).await, @r###"
-        error: metadata field project not found
-        "###);
+        assert_snapshot!(format_err(input).await, @"error: metadata field project not found");
     }
 
     #[test]
