@@ -4,8 +4,8 @@ use std::{collections::BTreeMap, num::NonZeroUsize};
 use url::Url;
 
 use uv_configuration::{
-    BuildIsolation, ExportFormat, IndexStrategy, KeyringProviderType, ProxyUrl, Reinstall,
-    RequiredVersion, TargetTriple, TrustedPublishing, Upgrade,
+    BuildIsolation, ExportFormat, IndexStrategy, KeyringProviderType, NoSources, ProxyUrl,
+    Reinstall, RequiredVersion, TargetTriple, TrustedPublishing, Upgrade,
 };
 use uv_distribution_types::{
     ConfigSettings, ExtraBuildVariables, Index, IndexUrl, PackageConfigSettings, PipExtraIndex,
@@ -182,6 +182,16 @@ impl Combine for Option<PackageConfigSettings> {
     }
 }
 
+impl Combine for Option<NoSources> {
+    /// Combine two source strategies by using the `combine` method if they're both `Some`.
+    fn combine(self, other: Self) -> Self {
+        match (self, other) {
+            (Some(a), Some(b)) => Some(a.combine(b)),
+            (a, b) => a.or(b),
+        }
+    }
+}
+
 impl Combine for Option<Upgrade> {
     fn combine(self, other: Self) -> Self {
         match (self, other) {
