@@ -6,7 +6,7 @@ use std::time::Duration;
 use uv_dirs::{system_config_file, user_config_dir};
 use uv_flags::EnvironmentFlags;
 use uv_fs::Simplified;
-use uv_static::EnvVars;
+use uv_static::{EnvVars, InvalidEnvironmentVariable, parse_boolish_environment_variable};
 use uv_warnings::warn_user;
 
 pub use crate::combine::*;
@@ -331,6 +331,7 @@ fn warn_uv_toml_masked_fields(options: &Options) {
                 link_mode,
                 compile_bytecode,
                 no_sources,
+                no_sources_package: _,
                 upgrade,
                 upgrade_package,
                 reinstall,
@@ -579,12 +580,8 @@ pub enum Error {
     )]
     PyprojectOnlyField(PathBuf, &'static str),
 
-    #[error("Failed to parse environment variable `{name}` with invalid value `{value}`: {err}")]
-    InvalidEnvironmentVariable {
-        name: String,
-        value: String,
-        err: String,
-    },
+    #[error(transparent)]
+    InvalidEnvironmentVariable(#[from] InvalidEnvironmentVariable),
 }
 
 #[derive(Copy, Clone, Debug)]
@@ -726,58 +723,6 @@ impl EnvironmentOptions {
     }
 }
 
-/// Parse a boolean environment variable.
-///
-/// Adapted from Clap's `BoolishValueParser` which is dual licensed under the MIT and Apache-2.0.
-pub fn parse_boolish_environment_variable(name: &'static str) -> Result<Option<bool>, Error> {
-    // See `clap_builder/src/util/str_to_bool.rs`
-    // We want to match Clap's accepted values
-
-    // True values are `y`, `yes`, `t`, `true`, `on`, and `1`.
-    const TRUE_LITERALS: [&str; 6] = ["y", "yes", "t", "true", "on", "1"];
-
-    // False values are `n`, `no`, `f`, `false`, `off`, and `0`.
-    const FALSE_LITERALS: [&str; 6] = ["n", "no", "f", "false", "off", "0"];
-
-    // Converts a string literal representation of truth to true or false.
-    //
-    // `false` values are `n`, `no`, `f`, `false`, `off`, and `0` (case insensitive).
-    //
-    // Any other value will be considered as `true`.
-    fn str_to_bool(val: impl AsRef<str>) -> Option<bool> {
-        let pat: &str = &val.as_ref().to_lowercase();
-        if TRUE_LITERALS.contains(&pat) {
-            Some(true)
-        } else if FALSE_LITERALS.contains(&pat) {
-            Some(false)
-        } else {
-            None
-        }
-    }
-
-    let Some(value) = std::env::var_os(name) else {
-        return Ok(None);
-    };
-
-    let Some(value) = value.to_str() else {
-        return Err(Error::InvalidEnvironmentVariable {
-            name: name.to_string(),
-            value: value.to_string_lossy().to_string(),
-            err: "expected a valid UTF-8 string".to_string(),
-        });
-    };
-
-    let Some(value) = str_to_bool(value) else {
-        return Err(Error::InvalidEnvironmentVariable {
-            name: name.to_string(),
-            value: value.to_string(),
-            err: "expected a boolish value".to_string(),
-        });
-    };
-
-    Ok(Some(value))
-}
-
 /// Parse a string environment variable.
 fn parse_string_environment_variable(name: &'static str) -> Result<Option<String>, Error> {
     match std::env::var(name) {
@@ -790,11 +735,13 @@ fn parse_string_environment_variable(name: &'static str) -> Result<Option<String
         }
         Err(e) => match e {
             std::env::VarError::NotPresent => Ok(None),
-            std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable {
-                name: name.to_string(),
-                value: err.to_string_lossy().to_string(),
-                err: "expected a valid UTF-8 string".to_string(),
-            }),
+            std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable(
+                InvalidEnvironmentVariable {
+                    name: name.to_string(),
+                    value: err.to_string_lossy().to_string(),
+                    err: "expected a valid UTF-8 string".to_string(),
+                },
+            )),
         },
     }
 }
@@ -809,11 +756,13 @@ where
         Err(e) => {
             return match e {
                 std::env::VarError::NotPresent => Ok(None),
-                std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable {
-                    name: name.to_string(),
-                    value: err.to_string_lossy().to_string(),
-                    err: "expected a valid UTF-8 string".to_string(),
-                }),
+                std::env::VarError::NotUnicode(err) => Err(Error::InvalidEnvironmentVariable(
+                    InvalidEnvironmentVariable {
+                        name: name.to_string(),
+                        value: err.to_string_lossy().to_string(),
+                        err: "expected a valid UTF-8 string".to_string(),
+                    },
+                )),
             };
         }
     };
@@ -823,11 +772,13 @@ where
 
     match value.parse::<T>() {
         Ok(v) => Ok(Some(v)),
-        Err(err) => Err(Error::InvalidEnvironmentVariable {
-            name: name.to_string(),
-            value,
-            err: err.to_string(),
-        }),
+        Err(err) => Err(Error::InvalidEnvironmentVariable(
+            InvalidEnvironmentVariable {
+                name: name.to_string(),
+                value,
+                err: err.to_string(),
+            },
+        )),
     }
 }
 
