@@ -15,7 +15,7 @@ use tracing::debug;
 
 /// Shells for which virtualenv activation scripts are available.
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
-#[allow(clippy::doc_markdown)]
+#[expect(clippy::doc_markdown)]
 pub enum Shell {
     /// Bourne Again SHell (bash)
     Bash,
