@@ -1,4 +1,4 @@
-use std::{env, io};
+use std::io;
 
 use assert_fs::fixture::{ChildPath, FileWriteStr, PathChild};
 use http::StatusCode;
@@ -180,8 +180,7 @@ async fn simple_http_500() {
         .arg("tqdm")
         .arg("--index-url")
         .arg(&mock_server_uri)
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -206,8 +205,7 @@ async fn simple_io_err() {
         .arg("tqdm")
         .arg("--index-url")
         .arg(&mock_server_uri)
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -235,8 +233,7 @@ async fn find_links_http_500() {
         .arg("--no-index")
         .arg("--find-links")
         .arg(&mock_server_uri)
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -263,8 +260,7 @@ async fn find_links_io_error() {
         .arg("--no-index")
         .arg("--find-links")
         .arg(&mock_server_uri)
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -294,8 +290,7 @@ async fn find_links_mixed_error() {
         .arg("--no-index")
         .arg("--find-links")
         .arg(&mock_server_uri)
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -323,8 +318,7 @@ async fn direct_url_http_500() {
     uv_snapshot!(filters, context
         .pip_install()
         .arg(format!("tqdm @ {tqdm_url}"))
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -351,8 +345,7 @@ async fn direct_url_io_error() {
     uv_snapshot!(filters, context
         .pip_install()
         .arg(format!("tqdm @ {tqdm_url}"))
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r#"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -364,7 +357,7 @@ async fn direct_url_io_error() {
       ├─▶ error sending request for url ([SERVER]/packages/d0/30/dc54f88dd4a2b5dc8a0279bdd7270e735851848b762aeb1c1184ed1f6b14/tqdm-4.67.1-py3-none-any.whl)
       ├─▶ client error (SendRequest)
       ╰─▶ connection closed before message completed
-    "#);
+    ");
 }
 
 /// Check the error message for direct package URL, a streaming request, when the server returns
@@ -382,8 +375,7 @@ async fn direct_url_mixed_error() {
     uv_snapshot!(filters, context
         .pip_install()
         .arg(format!("tqdm @ {tqdm_url}"))
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -441,8 +433,7 @@ async fn python_install_http_500() {
         .arg("cpython-3.10.0-darwin-aarch64-none")
         .arg("--python-downloads-json-url")
         .arg(python_downloads_json.path())
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -473,8 +464,7 @@ async fn python_install_io_error() {
         .arg("cpython-3.10.0-darwin-aarch64-none")
         .arg("--python-downloads-json-url")
         .arg(python_downloads_json.path())
-        .env_remove(EnvVars::UV_HTTP_RETRIES)
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -506,7 +496,7 @@ async fn install_http_retries() {
         .arg("anyio")
         .arg("--index")
         .arg(server.uri())
-        .env(EnvVars::UV_HTTP_RETRIES, "foo"), @r"
+        .env(EnvVars::UV_HTTP_RETRIES, "foo"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -520,7 +510,7 @@ async fn install_http_retries() {
         .arg("anyio")
         .arg("--index")
         .arg(server.uri())
-        .env(EnvVars::UV_HTTP_RETRIES, "-1"), @r"
+        .env(EnvVars::UV_HTTP_RETRIES, "-1"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -534,7 +524,7 @@ async fn install_http_retries() {
         .arg("anyio")
         .arg("--index")
         .arg(server.uri())
-        .env(EnvVars::UV_HTTP_RETRIES, "999999999999"), @r"
+        .env(EnvVars::UV_HTTP_RETRIES, "999999999999"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -549,7 +539,7 @@ async fn install_http_retries() {
         .arg("--index")
         .arg(server.uri())
         .env(EnvVars::UV_HTTP_RETRIES, "5")
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -581,7 +571,7 @@ async fn install_http_retry_low_level() {
         .arg("--index")
         .arg(server.uri())
         .env(EnvVars::UV_HTTP_RETRIES, "1")
-        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @r"
+        .env(EnvVars::UV_TEST_NO_HTTP_RETRY_DELAY, "true"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -631,8 +621,7 @@ async fn rfc9457_problem_details_license_violation() {
     let filters = vec![(mock_server_uri.as_str(), "[SERVER]")];
     uv_snapshot!(filters, context
         .pip_install()
-        .arg(format!("tqdm @ {tqdm_url}"))
-        .env_remove(EnvVars::UV_HTTP_RETRIES), @r"
+        .arg(format!("tqdm @ {tqdm_url}")), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -708,6 +697,7 @@ async fn proxy_invalid_url_not_a_url_in_uv_toml() {
 }
 
 /// Test that valid proxy URL in uv.toml routes requests through the proxy.
+#[cfg(feature = "pypi")]
 #[tokio::test]
 async fn proxy_valid_url_in_uv_toml() {
     let context = TestContext::new("3.12");
@@ -743,7 +733,7 @@ async fn proxy_valid_url_in_uv_toml() {
         .env_remove(EnvVars::HTTP_PROXY)
         .env_remove(EnvVars::HTTPS_PROXY)
         .env_remove(EnvVars::ALL_PROXY)
-        .env_remove(EnvVars::NO_PROXY), @r"
+        .env_remove(EnvVars::NO_PROXY), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -766,6 +756,7 @@ async fn proxy_valid_url_in_uv_toml() {
 }
 
 /// Test that https-proxy in uv.toml routes HTTPS requests through a CONNECT tunnel proxy.
+#[cfg(feature = "pypi")]
 #[test]
 fn proxy_https_proxy_in_uv_toml() {
     let context = TestContext::new("3.12");
@@ -788,7 +779,7 @@ fn proxy_https_proxy_in_uv_toml() {
         .env_remove(EnvVars::HTTP_PROXY)
         .env_remove(EnvVars::HTTPS_PROXY)
         .env_remove(EnvVars::ALL_PROXY)
-        .env_remove(EnvVars::NO_PROXY), @r"
+        .env_remove(EnvVars::NO_PROXY), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -802,6 +793,7 @@ fn proxy_https_proxy_in_uv_toml() {
 }
 
 /// Test that no-proxy in uv.toml bypasses the proxy for specified hosts.
+#[cfg(feature = "pypi")]
 #[tokio::test]
 async fn proxy_no_proxy_in_uv_toml() {
     let context = TestContext::new("3.12");
@@ -846,7 +838,7 @@ no-proxy = ["{target_host}"]
         .env_remove(EnvVars::HTTP_PROXY)
         .env_remove(EnvVars::HTTPS_PROXY)
         .env_remove(EnvVars::ALL_PROXY)
-        .env_remove(EnvVars::NO_PROXY), @r"
+        .env_remove(EnvVars::NO_PROXY), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -869,6 +861,7 @@ no-proxy = ["{target_host}"]
 }
 
 /// Test that proxy URLs without a scheme in uv.toml default to http://.
+#[cfg(feature = "pypi")]
 #[tokio::test]
 async fn proxy_schemeless_url_in_uv_toml() {
     let context = TestContext::new("3.12");
@@ -910,7 +903,7 @@ async fn proxy_schemeless_url_in_uv_toml() {
         .env_remove(EnvVars::HTTP_PROXY)
         .env_remove(EnvVars::HTTPS_PROXY)
         .env_remove(EnvVars::ALL_PROXY)
-        .env_remove(EnvVars::NO_PROXY), @r"
+        .env_remove(EnvVars::NO_PROXY), @"
     success: true
     exit_code: 0
     ----- stdout -----
