@@ -14,14 +14,14 @@ use crate::common::{TestContext, uv_snapshot};
 fn show_empty() {
     let context = TestContext::new("3.12");
 
-    uv_snapshot!(context.pip_show(), @r###"
+    uv_snapshot!(context.pip_show(), @"
     success: false
     exit_code: 1
     ----- stdout -----
 
     ----- stderr -----
     warning: Please provide a package name or names.
-    "###
+    "
     );
 }
 
@@ -37,7 +37,7 @@ fn show_requires_multiple() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -51,12 +51,12 @@ fn show_requires_multiple() -> Result<()> {
      + idna==3.6
      + requests==2.31.0
      + urllib3==2.2.1
-    "###
+    "
     );
 
     context.assert_command("import requests").success();
     uv_snapshot!(context.filters(), context.pip_show()
-        .arg("requests"), @r###"
+        .arg("requests"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -67,7 +67,7 @@ fn show_requires_multiple() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -87,7 +87,7 @@ fn show_python_version_marker() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -97,7 +97,7 @@ fn show_python_version_marker() -> Result<()> {
     Prepared 1 package in [TIME]
     Installed 1 package in [TIME]
      + click==8.1.7
-    "###
+    "
     );
 
     context.assert_command("import click").success();
@@ -108,7 +108,7 @@ fn show_python_version_marker() -> Result<()> {
     }
 
     uv_snapshot!(filters, context.pip_show()
-        .arg("click"), @r###"
+        .arg("click"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -119,7 +119,7 @@ fn show_python_version_marker() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -137,7 +137,7 @@ fn show_found_single_package() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -147,13 +147,13 @@ fn show_found_single_package() -> Result<()> {
     Prepared 1 package in [TIME]
     Installed 1 package in [TIME]
      + markupsafe==2.1.3
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").success();
 
     uv_snapshot!(context.filters(), context.pip_show()
-        .arg("markupsafe"), @r###"
+        .arg("markupsafe"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -164,7 +164,7 @@ fn show_found_single_package() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -186,7 +186,7 @@ fn show_found_multiple_packages() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -197,14 +197,14 @@ fn show_found_multiple_packages() -> Result<()> {
     Installed 2 packages in [TIME]
      + markupsafe==2.1.3
      + pip==21.3.1
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").success();
 
     uv_snapshot!(context.filters(), context.pip_show()
         .arg("markupsafe")
-        .arg("pip"), @r###"
+        .arg("pip"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -221,7 +221,7 @@ fn show_found_multiple_packages() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -243,7 +243,7 @@ fn show_found_one_out_of_three() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -254,7 +254,7 @@ fn show_found_one_out_of_three() -> Result<()> {
     Installed 2 packages in [TIME]
      + markupsafe==2.1.3
      + pip==21.3.1
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").success();
@@ -262,7 +262,7 @@ fn show_found_one_out_of_three() -> Result<()> {
     uv_snapshot!(context.filters(), context.pip_show()
         .arg("markupsafe")
         .arg("flask")
-        .arg("django"), @r###"
+        .arg("django"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -274,7 +274,7 @@ fn show_found_one_out_of_three() -> Result<()> {
 
     ----- stderr -----
     warning: Package(s) not found for: django, flask
-    "###
+    "
     );
 
     Ok(())
@@ -296,7 +296,7 @@ fn show_found_one_out_of_two_quiet() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -307,7 +307,7 @@ fn show_found_one_out_of_two_quiet() -> Result<()> {
     Installed 2 packages in [TIME]
      + markupsafe==2.1.3
      + pip==21.3.1
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").success();
@@ -316,13 +316,13 @@ fn show_found_one_out_of_two_quiet() -> Result<()> {
     uv_snapshot!(context.pip_show()
         .arg("markupsafe")
         .arg("flask")
-        .arg("--quiet"), @r###"
+        .arg("--quiet"), @"
     success: true
     exit_code: 0
     ----- stdout -----
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -344,7 +344,7 @@ fn show_empty_quiet() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -355,7 +355,7 @@ fn show_empty_quiet() -> Result<()> {
     Installed 2 packages in [TIME]
      + markupsafe==2.1.3
      + pip==21.3.1
-    "###
+    "
     );
 
     context.assert_command("import markupsafe").success();
@@ -363,13 +363,13 @@ fn show_empty_quiet() -> Result<()> {
     // Flask isn't installed, so the command should fail.
     uv_snapshot!(context.pip_show()
         .arg("flask")
-        .arg("--quiet"), @r###"
+        .arg("--quiet"), @"
     success: false
     exit_code: 1
     ----- stdout -----
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -394,7 +394,7 @@ fn show_editable() -> Result<()> {
         .success();
 
     uv_snapshot!(context.filters(), context.pip_show()
-        .arg("poetry-editable"), @r###"
+        .arg("poetry-editable"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -406,7 +406,7 @@ fn show_editable() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -428,7 +428,7 @@ fn show_required_by_multiple() -> Result<()> {
         .pip_install()
         .arg("-r")
         .arg("requirements.txt")
-        .arg("--strict"), @r###"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -444,14 +444,14 @@ fn show_required_by_multiple() -> Result<()> {
      + requests==2.31.0
      + sniffio==1.3.1
      + urllib3==2.2.1
-    "###
+    "
     );
 
     context.assert_command("import requests").success();
 
     // idna is required by anyio and requests
     uv_snapshot!(context.filters(), context.pip_show()
-        .arg("idna"), @r###"
+        .arg("idna"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -462,7 +462,7 @@ fn show_required_by_multiple() -> Result<()> {
     Required-by: anyio, requests
 
     ----- stderr -----
-    "###
+    "
     );
 
     Ok(())
@@ -476,7 +476,7 @@ fn show_files() {
     uv_snapshot!(context
         .pip_install()
         .arg("requests==2.31.0")
-        .arg("--strict"), @r#"
+        .arg("--strict"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -490,12 +490,12 @@ fn show_files() {
      + idna==3.6
      + requests==2.31.0
      + urllib3==2.2.1
-    "#
+    "
     );
 
     // Windows has a different files order.
     #[cfg(not(windows))]
-    uv_snapshot!(context.filters(), context.pip_show().arg("requests").arg("--files"), @r#"
+    uv_snapshot!(context.filters(), context.pip_show().arg("requests").arg("--files"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -532,7 +532,7 @@ fn show_files() {
       requests/utils.py
 
     ----- stderr -----
-    "#);
+    ");
 }
 
 #[test]
@@ -559,7 +559,7 @@ fn show_target() -> Result<()> {
     uv_snapshot!(context.filters(), context.pip_show()
         .arg("markupsafe")
         .arg("--target")
-        .arg(target.path()), @r###"
+        .arg(target.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -570,18 +570,18 @@ fn show_target() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     // Without --target, the package should not be found.
-    uv_snapshot!(context.pip_show().arg("markupsafe"), @r###"
+    uv_snapshot!(context.pip_show().arg("markupsafe"), @"
     success: false
     exit_code: 1
     ----- stdout -----
 
     ----- stderr -----
     warning: Package(s) not found for: markupsafe
-    "###
+    "
     );
 
     Ok(())
@@ -611,7 +611,7 @@ fn show_prefix() -> Result<()> {
     uv_snapshot!(context.filters(), context.pip_show()
         .arg("markupsafe")
         .arg("--prefix")
-        .arg(prefix.path()), @r###"
+        .arg(prefix.path()), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -622,18 +622,18 @@ fn show_prefix() -> Result<()> {
     Required-by:
 
     ----- stderr -----
-    "###
+    "
     );
 
     // Without --prefix, the package should not be found.
-    uv_snapshot!(context.pip_show().arg("markupsafe"), @r###"
+    uv_snapshot!(context.pip_show().arg("markupsafe"), @"
     success: false
     exit_code: 1
     ----- stdout -----
 
     ----- stderr -----
     warning: Package(s) not found for: markupsafe
-    "###
+    "
     );
 
     Ok(())
