@@ -14,7 +14,7 @@ fn python_pin() {
     let context: TestContext = TestContext::new_with_versions(&["3.11", "3.12"]);
 
     // Without arguments, we attempt to read the current pin (which does not exist yet)
-    uv_snapshot!(context.filters(), context.python_pin(), @r"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -24,146 +24,132 @@ fn python_pin() {
     ");
 
     // Given an argument, we pin to that version
-    uv_snapshot!(context.filters(), context.python_pin().arg("any"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("any"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `any`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r#"any"#);
+    assert_snapshot!(python_version, @"any");
 
     // Without arguments, we read the current pin
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
     any
 
     ----- stderr -----
-    "###);
+    ");
 
     // We should not mutate the file
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r#"any"#);
+    assert_snapshot!(python_version, @"any");
 
     // Request Python 3.12
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `any` -> `3.12`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    3.12
-    "###);
+    assert_snapshot!(python_version, @"3.12");
 
     // Request Python 3.11
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `3.12` -> `3.11`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    3.11
-    "###);
+    assert_snapshot!(python_version, @"3.11");
 
     // Request CPython
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `3.11` -> `cpython`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    cpython
-    "###);
+    assert_snapshot!(python_version, @"cpython");
 
     // Request CPython 3.12
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `cpython` -> `cpython@3.12`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    cpython@3.12
-    "###);
+    assert_snapshot!(python_version, @"cpython@3.12");
 
     // Request CPython 3.12 via non-canonical syntax
-    uv_snapshot!(context.filters(), context.python_pin().arg("cp3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cp3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `cpython@3.12`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    cpython@3.12
-    "###);
+    assert_snapshot!(python_version, @"cpython@3.12");
 
     // Request CPython 3.12 via partial key syntax
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython-3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython-3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `cpython@3.12` -> `cpython-3.12-any-any-any`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(python_version, @r###"
-    cpython-3.12-any-any-any
-    "###);
+    assert_snapshot!(python_version, @"cpython-3.12-any-any-any");
 
     // Request a specific path
-    uv_snapshot!(context.filters(), context.python_pin().arg(&context.python_versions.first().unwrap().1), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg(&context.python_versions.first().unwrap().1), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `cpython-3.12-any-any-any` -> `[PYTHON-3.11]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(python_version, @r###"
-        [PYTHON-3.11]
-        "###);
+        assert_snapshot!(python_version, @"[PYTHON-3.11]");
     });
 
     // Request an implementation that is not installed
     // (skip on Windows because the snapshot is different and the behavior is not platform dependent)
     #[cfg(unix)]
     {
-        uv_snapshot!(context.filters(), context.python_pin().arg("pypy"), @r"
+        uv_snapshot!(context.filters(), context.python_pin().arg("pypy"), @"
         success: true
         exit_code: 0
         ----- stdout -----
@@ -174,16 +160,14 @@ fn python_pin() {
         ");
 
         let python_version = context.read(PYTHON_VERSION_FILENAME);
-        assert_snapshot!(python_version, @r###"
-        pypy
-        "###);
+        assert_snapshot!(python_version, @"pypy");
     }
 
     // Request a version that is not installed
     // (skip on Windows because the snapshot is different and the behavior is not platform dependent)
     #[cfg(unix)]
     {
-        uv_snapshot!(context.filters(), context.python_pin().arg("3.7"), @r###"
+        uv_snapshot!(context.filters(), context.python_pin().arg("3.7"), @"
         success: true
         exit_code: 0
         ----- stdout -----
@@ -191,12 +175,10 @@ fn python_pin() {
 
         ----- stderr -----
         warning: No interpreter found for Python 3.7 in managed installations or search path
-        "###);
+        ");
 
         let python_version = context.read(PYTHON_VERSION_FILENAME);
-        assert_snapshot!(python_version, @r###"
-    3.7
-    "###);
+        assert_snapshot!(python_version, @"3.7");
     }
 }
 
@@ -208,7 +190,7 @@ fn python_pin_global_if_no_local() -> Result<()> {
     uv.create_dir_all()?;
 
     // Without arguments, we attempt to read the current pin (which does not exist yet)
-    uv_snapshot!(context.filters(), context.python_pin(), @r"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -218,7 +200,7 @@ fn python_pin_global_if_no_local() -> Result<()> {
     ");
 
     // Given an argument, we globally pin to that version
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.11").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.11").arg("--global"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -228,14 +210,14 @@ fn python_pin_global_if_no_local() -> Result<()> {
     ");
 
     // If no local pin, use global.
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
     3.11
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -249,7 +231,7 @@ fn python_pin_global_use_local_if_available() -> Result<()> {
     uv.create_dir_all()?;
 
     // Given an argument, we globally pin to that version
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").arg("--global"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -259,14 +241,14 @@ fn python_pin_global_use_local_if_available() -> Result<()> {
     ");
 
     // With no local, we get the global pin
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
     3.12
 
     ----- stderr -----
-    "###);
+    ");
 
     let mut global_version_path = PathBuf::from(uv.path());
     global_version_path.push(PYTHON_VERSION_FILENAME);
@@ -274,55 +256,49 @@ fn python_pin_global_use_local_if_available() -> Result<()> {
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(global_python_version, @r###"
-        3.12
-        "###);
+        assert_snapshot!(global_python_version, @"3.12");
     });
 
     // Request Python 3.11 for local .python-version
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `3.11`
 
     ----- stderr -----
-    "###);
+    ");
 
     // Local should override global
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
     3.11
 
     ----- stderr -----
-    "###);
+    ");
 
     // We should still be able to check global pin
-    uv_snapshot!(context.filters(), context.python_pin().arg("--global"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--global"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     3.12
 
     ----- stderr -----
-    "###);
+    ");
 
     // Local .python-version exists and has the right version.
     let local_python_version = context.read(PYTHON_VERSION_FILENAME);
-    assert_snapshot!(local_python_version, @r###"
-    3.11
-    "###);
+    assert_snapshot!(local_python_version, @"3.11");
 
     // Global .python-version still exists and has the right version.
     let global_python_version = context.read(&global_version_path);
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(global_python_version, @r###"
-        3.12
-        "###);
+        assert_snapshot!(global_python_version, @"3.12");
     });
 
     Ok(())
@@ -338,7 +314,7 @@ fn python_pin_global_creates_parent_dirs() {
         "Global config directory should not exist yet."
     );
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").arg("--global"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -360,7 +336,7 @@ fn python_pin_global_creates_parent_dirs() {
 fn python_pin_no_python() {
     let context: TestContext = TestContext::new_with_versions(&[]);
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -386,47 +362,47 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
         "#,
     )?;
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.10"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.10"), @"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
     error: The requested Python version `3.10` is incompatible with the project `requires-python` value of `>=3.11`.
-    "###);
+    ");
 
     // Request a implementation version that is incompatible
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10"), @"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
     error: The requested Python version `cpython@3.10` is incompatible with the project `requires-python` value of `>=3.11`.
-    "###);
+    ");
 
     // Request an incompatible version with project discovery turned off
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10").arg("--no-project"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10").arg("--no-project"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `cpython@3.10`
 
     ----- stderr -----
-    "###);
+    ");
 
     // And, as an alias, workspace discovery
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10").arg("--no-workspace"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.10").arg("--no-workspace"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `cpython@3.10`
 
     ----- stderr -----
-    "###);
+    ");
 
     // Request a complex version range that resolves to an incompatible version
-    uv_snapshot!(context.filters(), context.python_pin().arg(">3.8,<3.11"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg(">3.8,<3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -434,46 +410,44 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The requested Python version `>3.8, <3.11` resolves to `3.10.[X]` which  is incompatible with the project `requires-python` value of `>=3.11`.
-    "###);
+    ");
 
     // Request a version that is compatible
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `>3.8, <3.11` -> `3.11`
 
     ----- stderr -----
-    "###);
+    ");
 
     // Request a version that is compatible and uses a Python variant
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.13t"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.13t"), @"
     success: true
     exit_code: 0
     ----- stdout -----
-    Updated `.python-version` from `3.11` -> `3.13t`
+    Updated `.python-version` from `3.11` -> `3.13+freethreaded`
 
     ----- stderr -----
-    warning: No interpreter found for Python 3.13t in [PYTHON SOURCES]
+    warning: No interpreter found for Python 3.13+freethreaded in [PYTHON SOURCES]
     ");
 
     // Request a implementation version that is compatible
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.11"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython@3.11"), @"
     success: true
     exit_code: 0
     ----- stdout -----
-    Updated `.python-version` from `3.13t` -> `cpython@3.11`
+    Updated `.python-version` from `3.13+freethreaded` -> `cpython@3.11`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
         filters => context.filters(),
     }, {
-        assert_snapshot!(python_version, @r###"
-        cpython@3.11
-        "###);
+        assert_snapshot!(python_version, @"cpython@3.11");
     });
 
     // Updating `requires-python` should affect `uv python pin` compatibilities.
@@ -487,7 +461,7 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
         "#,
     )?;
 
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -495,10 +469,10 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The pinned Python version `cpython@3.11` is incompatible with the project `requires-python` value of `>=3.12`.
-    "###);
+    ");
 
     // Request a implementation that resolves to a compatible version
-    uv_snapshot!(context.filters(), context.python_pin().arg("cpython"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("cpython"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -506,9 +480,9 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The requested Python version `cpython` resolves to `3.10.[X]` which  is incompatible with the project `requires-python` value of `>=3.12`.
-    "###);
+    ");
 
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -516,10 +490,10 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The pinned Python version `cpython` resolves to `3.10.[X]` which  is incompatible with the project `requires-python` value of `>=3.12`.
-    "###);
+    ");
 
     // Request a complex version range that resolves to a compatible version
-    uv_snapshot!(context.filters(), context.python_pin().arg(">3.8,<3.12"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg(">3.8,<3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -527,9 +501,9 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The requested Python version `>3.8, <3.12` resolves to `3.10.[X]` which  is incompatible with the project `requires-python` value of `>=3.12`.
-    "###);
+    ");
 
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -537,7 +511,7 @@ fn python_pin_compatible_with_requires_python() -> Result<()> {
 
     ----- stderr -----
     warning: The pinned Python version `>3.8, <3.12` resolves to `3.10.[X]` which  is incompatible with the project `requires-python` value of `>=3.12`.
-    "###);
+    ");
 
     Ok(())
 }
@@ -569,7 +543,7 @@ fn warning_pinned_python_version_not_installed() -> Result<()> {
         warning: Failed to resolve pinned Python version `3.12`: No interpreter found for Python 3.12 in managed installations, search path, or registry
         "###);
     } else {
-        uv_snapshot!(context.filters(), context.python_pin(), @r###"
+        uv_snapshot!(context.filters(), context.python_pin(), @"
         success: true
         exit_code: 0
         ----- stdout -----
@@ -577,7 +551,7 @@ fn warning_pinned_python_version_not_installed() -> Result<()> {
 
         ----- stderr -----
         warning: Failed to resolve pinned Python version `3.12`: No interpreter found for Python 3.12 in managed installations or search path
-        "###);
+        ");
     }
 
     Ok(())
@@ -587,7 +561,7 @@ fn warning_pinned_python_version_not_installed() -> Result<()> {
 #[test]
 fn python_pin_resolve_no_python() {
     let context: TestContext = TestContext::new_with_versions(&[]).with_filtered_python_sources();
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.12"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -604,14 +578,14 @@ fn python_pin_resolve() {
     let context: TestContext = TestContext::new_with_versions(&["3.12", "3.13"]);
 
     // We pin the first interpreter on the path
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("any"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("any"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `[PYTHON-3.12]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -621,14 +595,14 @@ fn python_pin_resolve() {
     });
 
     // Request Python 3.13
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.13"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.13"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `[PYTHON-3.12]` -> `[PYTHON-3.13]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -638,14 +612,14 @@ fn python_pin_resolve() {
     });
 
     // Request Python 3.13
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.13"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.13"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `[PYTHON-3.13]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -655,14 +629,14 @@ fn python_pin_resolve() {
     });
 
     // Request CPython
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `[PYTHON-3.13]` -> `[PYTHON-3.12]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -672,14 +646,14 @@ fn python_pin_resolve() {
     });
 
     // Request CPython 3.13
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython@3.13"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython@3.13"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Updated `.python-version` from `[PYTHON-3.12]` -> `[PYTHON-3.13]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -689,14 +663,14 @@ fn python_pin_resolve() {
     });
 
     // Request CPython 3.13 via partial key syntax
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython-3.13"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("cpython-3.13"), @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `[PYTHON-3.13]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -711,14 +685,14 @@ fn python_pin_resolve() {
 
     uv_snapshot!(context.filters(), context.python_pin().arg("--resolved")
     .arg(format!("cpython-3.13-{os}-{arch}"))
-    , @r###"
+    , @"
     success: true
     exit_code: 0
     ----- stdout -----
     Pinned `.python-version` to `[PYTHON-3.13]`
 
     ----- stderr -----
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -730,7 +704,7 @@ fn python_pin_resolve() {
     // Request an implementation that is not installed
     // (skip on Windows because the snapshot is different and the behavior is not platform dependent)
     #[cfg(unix)]
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("pypy"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("pypy"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -751,14 +725,14 @@ fn python_pin_resolve() {
     // Request a version that is not installed
     // (skip on Windows because the snapshot is different and the behavior is not platform dependent)
     #[cfg(unix)]
-    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.7"), @r###"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--resolved").arg("3.7"), @"
     success: false
     exit_code: 2
     ----- stdout -----
 
     ----- stderr -----
     error: No interpreter found for Python 3.7 in managed installations or search path
-    "###);
+    ");
 
     let python_version = context.read(PYTHON_VERSION_FILENAME);
     insta::with_settings!({
@@ -781,7 +755,7 @@ fn python_pin_with_comments() -> Result<()> {
 
     let version_file = context.temp_dir.child(PYTHON_VERSION_FILENAME);
     version_file.write_str(content)?;
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -789,12 +763,12 @@ fn python_pin_with_comments() -> Result<()> {
     3.10
 
     ----- stderr -----
-    "###);
+    ");
     fs_err::remove_file(version_file)?;
 
     let versions_file = context.temp_dir.child(PYTHON_VERSIONS_FILENAME);
     versions_file.write_str(content)?;
-    uv_snapshot!(context.filters(), context.python_pin(), @r###"
+    uv_snapshot!(context.filters(), context.python_pin(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -802,7 +776,7 @@ fn python_pin_with_comments() -> Result<()> {
     3.10
 
     ----- stderr -----
-    "###);
+    ");
 
     Ok(())
 }
@@ -813,7 +787,7 @@ fn python_pin_install() {
     let context: TestContext = TestContext::new_with_versions(&[]).with_filtered_python_sources();
 
     // Should not install 3.12 when downloads are not automatic
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -823,7 +797,7 @@ fn python_pin_install() {
     warning: No interpreter found for Python 3.12 in [PYTHON SOURCES]
     ");
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").env(EnvVars::UV_PYTHON_DOWNLOADS, "auto"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("3.12").env(EnvVars::UV_PYTHON_DOWNLOADS, "auto"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -837,7 +811,7 @@ fn python_pin_install() {
 fn python_pin_rm() {
     let context: TestContext = TestContext::new_with_versions(&["3.12"]);
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -848,7 +822,7 @@ fn python_pin_rm() {
 
     // Create and remove a local pin
     context.python_pin().arg("3.12").assert().success();
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -857,7 +831,7 @@ fn python_pin_rm() {
     ----- stderr -----
     ");
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -868,7 +842,7 @@ fn python_pin_rm() {
 
     // Global does not detect the local pin
     context.python_pin().arg("3.12").assert().success();
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @"
     success: false
     exit_code: 2
     ----- stdout -----
@@ -884,7 +858,7 @@ fn python_pin_rm() {
         .assert()
         .success();
 
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm").arg("--global"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -902,7 +876,7 @@ fn python_pin_rm() {
         .success();
 
     // Remove the local pin
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -912,7 +886,7 @@ fn python_pin_rm() {
     ");
 
     // The global pin should not be removed without `--global`
-    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @r"
+    uv_snapshot!(context.filters(), context.python_pin().arg("--rm"), @"
     success: false
     exit_code: 2
     ----- stdout -----
